@@ -2,7 +2,7 @@
 #
 # The MIT License (MIT)
 #
-# Copyright (c) Crossbar.io Technologies GmbH
+# Copyright (c) typedef int GmbH
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -23,26 +23,3 @@
 # THE SOFTWARE.
 #
 ###############################################################################
-
-from __future__ import absolute_import, print_function
-
-
-class FakeTransport(object):
-    _written = b""
-    _open = True
-
-    def write(self, msg):
-        if not self._open:
-            raise Exception("Can't write to a closed connection")
-        self._written = self._written + msg
-
-    def loseConnection(self):
-        self._open = False
-
-    def registerProducer(self, producer, streaming):
-        # https://twistedmatrix.com/documents/current/api/twisted.internet.interfaces.IConsumer.html
-        raise NotImplementedError
-
-    def unregisterProducer(self):
-        # do nothing is correct! until we fake implement registerProducer ..;)
-        pass
