@@ -2,7 +2,7 @@
 #
 # The MIT License (MIT)
 #
-# Copyright (c) Crossbar.io Technologies GmbH
+# Copyright (c) typedef int GmbH
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -530,8 +530,10 @@ def pbkdf2(data, salt, iterations=1000, keylen=32, hashfunc=None):
         )
 
     backend = default_backend()
+
+    # https://cryptography.io/en/latest/hazmat/primitives/key-derivation-functions/#pbkdf2
     kdf = PBKDF2HMAC(
-        algorithm=getattr(hashes, hashfunc.upper()),
+        algorithm=getattr(hashes, hashfunc.upper())(),
         length=keylen,
         salt=salt,
         iterations=iterations,
